/*
 * This file is part of gtkD.
 *
 * gtkD is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version, with
 * some exceptions, please read the COPYING file.
 *
 * gtkD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with gtkD; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
 */

import gobject.Value;

import gio.IconIF;
import gio.ThemedIcon;

void main()
{
	Value val = new Value(true);
	assert(val.get!bool());

	val = new Value(42);
	assert(val.get!int() == 42);

	val = new Value(1.12);
	assert(val.get!double() == 1.12);

	ThemedIcon icon = new ThemedIcon("gnome-dev-cdrom-audio");
	val = new Value(icon);
	assert(val.get!ThemedIcon() is icon);
	assert(val.get!IconIF() is icon);
}
